unit unMBSPlayerMain;
{
This program is a player for Autodesk Animator Fli / Flc animation files.
It uses the MBS Fli Player component (Timer version 1)

This program may be distributed freely as long as the following conditions are kept:
(1) All attached documentation must be included without any modification
(2) The registered MBS Fli component may not be distributed.
(The unregistered version with nag-screen may be distributed)

Where can I find Fli files?
  - At our website you can find a few samples.
  - Create your own with Autodesk Animator
  - A lot of 3D drawing programs gives output in the Fli format

Visit or contact us:
  louw@gcs.co.za
  www.gcs.co.za/mbs/mbs.htm

Disclaimer:
You use this component at your own and exclusive risk.
}
interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Menus, ExtCtrls, Buttons, FliPlayerTimer, uniDib, FlicPlayer;

type
  TfoMain = class(TForm)
    MMenu: TMainMenu;
    File1: TMenuItem;
    Edit1: TMenuItem;
    Options1: TMenuItem;
    Help1: TMenuItem;
    Commands1: TMenuItem;
    OpenAnimation1: TMenuItem;
    N1: TMenuItem;
    Exit1: TMenuItem;
    Copy1: TMenuItem;
    Play1: TMenuItem;
    Pause1: TMenuItem;
    Stop1: TMenuItem;
    SeekFrame1: TMenuItem;
    About1: TMenuItem;
    Position1: TMenuItem;
    Left1: TMenuItem;
    Right1: TMenuItem;
    Center1: TMenuItem;
    ButtonPanel: TPanel;
    SpeedButton1: TSpeedButton;
    SpeedButton2: TSpeedButton;
    SpeedButton3: TSpeedButton;
    SpeedButton4: TSpeedButton;
    SpeedButton5: TSpeedButton;
    Stretch1: TMenuItem;
    Loop1: TMenuItem;
    OD: TOpenDialog;
    NextFrame1: TMenuItem;
    PrevFrame1: TMenuItem;
    AnimationOptions1: TMenuItem;
    N2: TMenuItem;
    ResizeWindow1: TMenuItem;
    HideAnimation1: TMenuItem;
    AniPanel: TPanel;
    Fli: TFliPlayerTimer;
    procedure OpenAnimation1Click(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure Left1Click(Sender: TObject);
    procedure Right1Click(Sender: TObject);
    procedure Center1Click(Sender: TObject);
    procedure Stretch1Click(Sender: TObject);
    procedure Exit1Click(Sender: TObject);
    procedure Loop1Click(Sender: TObject);
    procedure Play1Click(Sender: TObject);
    procedure Stop1Click(Sender: TObject);
    procedure Pause1Click(Sender: TObject);
    procedure ResizeWindow1Click(Sender: TObject);
    procedure PrevFrame1Click(Sender: TObject);
    procedure NextFrame1Click(Sender: TObject);
    procedure SeekFrame1Click(Sender: TObject);
    procedure FormResize(Sender: TObject);
    procedure Copy1Click(Sender: TObject);
    procedure HideAnimation1Click(Sender: TObject);
    procedure AnimationOptions1Click(Sender: TObject);
    procedure Dummy1Click(Sender: TObject);
    procedure FormKeyPress(Sender: TObject; var Key: Char);
    procedure FormClick(Sender: TObject);
    procedure About1Click(Sender: TObject);
    procedure FliFliNextFrame(Sender: TObject; FrameNo: Word);

    //Removed this function as it needed another component
{    procedure DropWatch1FilesDropped(Sender: TObject; X, Y: Integer;
      Files: TStringList);}

  private
    { Private declarations }

    Procedure WriteCaption;
  public
    { Public declarations }
  end;

Procedure RestoreOld;

var
  foMain     : TfoMain;
  LastFrame  : Cardinal;  //Frame last shown - used for preview
  H          : FliHeader; //Header information of a Fli file
  OnlyFName  : String;    //Filename without the path
  LoopFrames : Cardinal = 0;
  FrameCount : Cardinal = 0;

  OldLoopFrames,
  OldInterval,
  OldSpeed      : Cardinal;
  OldLoop,
  OldStretch    : Boolean;
  OldPosition   : TFliPos;
  Test          : Boolean = False;


implementation

uses unSeekFrame, ClipBrd, unAniSettings2, unAboutMBS;

{$R *.DFM}


Procedure TfoMain.WriteCaption;
Begin
 Case Fli.State of
  FliPlay  : foMain.Caption:= 'MBS Play - '+OnlyFName+'(Play)';
  FliStop  : foMain.Caption:= 'MBS Play - '+OnlyFName+'(Stop, Frm:'+IntToStr(LastFrame)+'/'+InttoStr(Fli.TotalFrames)+')';
  FliPause : foMain.Caption:= 'MBS Play - '+OnlyFName+'(Pause, Frm:'+IntToStr(LastFrame)+'/'+InttoStr(Fli.TotalFrames)+')';
 end;
end;

Procedure RestoreOld;
Begin
  LoopFrames:=OldLoopFrames;
  foMain.Fli.TimerInterval:=OldInterval;
  foMain.Fli.SpeedOverride:=OldSpeed;
  foMain.Fli.Loop:=OldLoop;
  foMain.Fli.Stretch:=OldStretch;
  Test:=False;
end;

procedure TfoMain.OpenAnimation1Click(Sender: TObject);
Var
 LoadIt : Boolean;
 Index  : Cardinal;
begin
 fli.Align:=alClient;
 IF OD.Execute then
  Begin
   Fli.SpeedOverride:=0;
   AnimationOptions1.Enabled:=False;
   Fli.FileName:=OD.FileName;
   OnlyFName:=ExtractFileName(Fli.FileName);
   Index:=Pos('.',OnlyFName);
   IF Index <> 0 then
    OnlyFName:=Copy(OnlyFName,1,Index-1);
   LoadIt:=True;
   IF Not Fli.ReadHeader(Fli.FileName,H) then
    IF MessageDlg('File not a true Fli file. Must it still be loaded?',mtWarning,[mbYes,mbCancel],0) = mrYes then
     LoadIt:=True Else LoadIt:=False;
   IF LoadIt then
     Begin
       Fli.Preview(1);
       LastFrame:=1;
       FoMain.ClientHeight:=H.height+4+ButtonPanel.Height;
       FoMain.ClientWidth:=H.width+4;
       ResizeWindow1.Checked:=True;
       AnimationOptions1.Enabled:=True;
       HideAnimation1.Checked:=False;
       Fli.Visible:=True;

       LoopFrames:=0;
       FrameCount:=0;
       OldLoopFrames:=LoopFrames;
       OldInterval:=FoMain.Fli.TimerInterval;
       OldLoop:=FoMain.Fli.Loop;
       OldStretch:=foMain.Fli.Stretch;
       OldSpeed:=FoMain.Fli.SpeedOverride;
       Test:=False;
     end;
  End;
end;

procedure TfoMain.FormCreate(Sender: TObject);
begin
  LastFrame:=1;
end;

procedure TfoMain.FormDestroy(Sender: TObject);
begin
 Fli.Free;
end;

procedure TfoMain.Left1Click(Sender: TObject);
begin
 Left1.Checked:=True;
 Right1.Checked:=False;
 Center1.Checked:=False;
 Fli.FliPos:=FliLeft;

end;

procedure TfoMain.Right1Click(Sender: TObject);
begin
 Left1.Checked:=False;
 Right1.Checked:=True;
 Center1.Checked:=False;
 Fli.FliPos:=FliRight;
end;

procedure TfoMain.Center1Click(Sender: TObject);
begin
 Left1.Checked:=False;
 Right1.Checked:=False;
 Center1.Checked:=True;
 Fli.FliPos:=FliCentre;
end;

procedure TfoMain.Stretch1Click(Sender: TObject);
begin
 Stretch1.Checked:=Not Stretch1.Checked;
 Fli.Stretch:=Stretch1.Checked;
end;

procedure TfoMain.Exit1Click(Sender: TObject);
begin
 Close;
end;

procedure TfoMain.Loop1Click(Sender: TObject);
begin
 Loop1.Checked:=Not Loop1.Checked;
 Fli.Loop:=Loop1.Checked;
end;

procedure TfoMain.Play1Click(Sender: TObject);
begin
 Fli.Play;
 WriteCaption;
 FrameCount:=0;

 IF Test then
   foAniSettings2.ShowModal;
end;

procedure TfoMain.Stop1Click(Sender: TObject);
begin
 Fli.Stop;
 WriteCaption;
 FrameCount:=0;

 IF Test then
   foAniSettings2.ShowModal;
end;

procedure TfoMain.Pause1Click(Sender: TObject);
begin
 IF Fli.State=FliPause then
  Fli.Continue
 Else Fli.Pause;
 WriteCaption;
end;

procedure TfoMain.ResizeWindow1Click(Sender: TObject);
begin
   IF Fli.ReadHeader(Fli.FileName,H) then
     Begin
       foMain.WindowState:=wsNormal;
       FoMain.ClientHeight:=H.height+4+ButtonPanel.Height;
       FoMain.ClientWidth:=H.width+4;
       ResizeWindow1.Checked:=True;
     end;
end;

procedure TfoMain.PrevFrame1Click(Sender: TObject);
begin
  IF Fli.State in [FliPlay,FliPause] then
    Fli.SeekFrame(Fli.CurrentFrame-1)
  Else
   Begin
     If LastFrame > 1 then
       Dec(LastFrame);
     Fli.Preview(LastFrame);
   end;
   
   WriteCaption;
end;

procedure TfoMain.NextFrame1Click(Sender: TObject);
begin
 IF Fli.State in [FliPlay,FliPause] then
    Fli.SeekFrame(Fli.CurrentFrame+1)
  Else
   Begin
    Fli.Play;
    Fli.Pause;
    Fli.SeekFrame(LastFrame+1);
   End;

   // Preview below opens the Fli, Play the Fli, uses seekframe to
   // seek correct frame and then Stops the Fli. To keep the Fli open
   // is much faster.

  { Begin
     If LastFrame < H.framecount then
       Inc(LastFrame);
     Fli.Preview(LastFrame);
   end;}

   WriteCaption;
end;

procedure TfoMain.SeekFrame1Click(Sender: TObject);
begin
 foSeekFrame.SpinEdit1.MaxValue:=Fli.TotalFrames;
 foSeekFrame.ShowModal;
 If foSeekFrame.ModalResult=mrOK then
 Begin
   LastFrame:=foSeekFrame.SpinEdit1.Value;
   IF Fli.State in [FliPlay,FliPause] then
      Fli.SeekFrame(LastFrame)
    Else
     Begin
      Fli.Play;
      Fli.Pause;
      Fli.SeekFrame(LastFrame);
     End;
 end;
 WriteCaption;
end;

procedure TfoMain.FormResize(Sender: TObject);
begin
 ResizeWindow1.Checked:=False;
end;

procedure TfoMain.Copy1Click(Sender: TObject);
Var
 BM : Tbitmap;

begin
 //Copy bitmap to clipboard
 Bm:=TBitmap.Create;
 With bm do
  begin
    width:=fli.Width;
    Height:=fli.Height;
    pixelformat:=pf24bit;
  end;
   Bitblt(bm.canvas.handle,0,0,fli.width,fli.Height,
   Fli.canvas.handle,0,0,srcCopy);{}
  Clipboard.Assign(bm);
  bm.Free;
end;

procedure TfoMain.HideAnimation1Click(Sender: TObject);
begin
 If Fli.State in [FliPlay,FliPause] then
  Fli.Stop;
 HideAnimation1.Checked:=Not HideAnimation1.Checked;
 Fli.Visible:=Not HideAnimation1.Checked;
end;

procedure TfoMain.AnimationOptions1Click(Sender: TObject);
begin
  foAniSettings2.ShowModal;
end;

procedure TfoMain.Dummy1Click(Sender: TObject);
begin
 foAniSettings2.Showmodal;
end;

procedure TfoMain.FormKeyPress(Sender: TObject; var Key: Char);
begin
   IF Test then
     Begin
      foAniSettings2.ShowModal;
     End;
end;

procedure TfoMain.FormClick(Sender: TObject);
begin
 IF Test then
     Begin
      foAniSettings2.ShowModal;
     End;
end;

procedure TfoMain.About1Click(Sender: TObject);
begin
 foAbout.ShowModal;
end;

procedure TfoMain.FliFliNextFrame(Sender: TObject;
  FrameNo: Word);
begin
  LastFrame:=FrameNo;
 Inc(FrameCount);
 IF ((FrameCount>=LoopFrames) and (LoopFrames > 0)) or ((Fli.Loop=False) and (FrameNo=Fli.TotalFrames)) then
  Begin
    Fli.Stop;
    IF Test then
     Begin
      foAniSettings2.ShowModal;
     End;
  End;
end;

// I removed this functionality
// This event was called whenever a file was dropped on the panel
// If it was a FLI file the animation was loaded
(*procedure TfoMain.DropWatch1FilesDropped(Sender: TObject; X, Y: Integer;
  Files: TStringList);
Var
 LoadIt : Boolean;
 Index  : Cardinal;
begin
   Fli.Filename:=Files.Strings[0];
   AnimationOptions1.Enabled:=False;
   OnlyFName:=ExtractFileName(Fli.FileName);
   Index:=Pos('.',OnlyFName);
   IF Index <> 0 then
    OnlyFName:=Copy(OnlyFName,1,Index-1);
   LoadIt:=True;
   IF Not Fli.ReadHeader(Fli.FileName,H) then
    IF MessageDlg('File not a true Fli file. Must it still be loaded?',mtWarning,[mbYes,mbCancel],0) = mrYes then
     LoadIt:=True Else LoadIt:=False;
   IF LoadIt then
     Begin
       Fli.Preview(1);
       LastFrame:=1;
       FoMain.ClientHeight:=H.height+4+ButtonPanel.Height;
       FoMain.ClientWidth:=H.width+4;
       ResizeWindow1.Checked:=True;
       AnimationOptions1.Enabled:=True;
       HideAnimation1.Checked:=False;
       Fli.Visible:=True;
     end;
  End; *)


end.
